==> aria2-1.16.4.tar.bz2: aria2-1.16.4/src/BtChokeMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "BtChokeMessage.h"
#include "Peer.h"
#include "BtMessageDispatcher.h"
#include "BtRequestFactory.h"
#include "SocketBuffer.h"

namespace aria2 {

const char BtChokeMessage::NAME[] = "choke";

BtChokeMessage::BtChokeMessage():ZeroBtMessage(ID, NAME) {}

BtChokeMessage* BtChokeMessage::create
(const unsigned char* data, size_t dataLength)
{
  return ZeroBtMessage::create<BtChokeMessage>(data, dataLength);
}

void BtChokeMessage::doReceivedAction()
{
  if(isMetadataGetMode()) {
    return;
  }
  getPeer()->peerChoking(true);
  getBtMessageDispatcher()->doChokedAction();
  getBtRequestFactory()->doChokedAction();
}

bool BtChokeMessage::sendPredicate() const
{
  return !getPeer()->amChoking();
}

namespace {
struct ThisProgressUpdate : public ProgressUpdate {
  ThisProgressUpdate(const SharedHandle<Peer>& peer,
                     BtMessageDispatcher* disp)
    : peer(peer), disp(disp) {}
  virtual void update(size_t length, bool complete)
  {
    if(complete) {
      peer->amChoking(true);
      disp->doChokingAction();
    }
  }
  SharedHandle<Peer> peer;
  BtMessageDispatcher* disp;
};
} // namespace

ProgressUpdate* BtChokeMessage::getProgressUpdate()
{
  return new ThisProgressUpdate(getPeer(), getBtMessageDispatcher());
}

} // namespace aria2

==> aria2_1.19.0.orig.tar.bz2: aria2-1.19.0/src/BtChokeMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "BtChokeMessage.h"
#include "Peer.h"
#include "BtMessageDispatcher.h"
#include "BtRequestFactory.h"
#include "SocketBuffer.h"

namespace aria2 {

const char BtChokeMessage::NAME[] = "choke";

BtChokeMessage::BtChokeMessage():ZeroBtMessage{ID, NAME} {}

std::unique_ptr<BtChokeMessage> BtChokeMessage::create
(const unsigned char* data, size_t dataLength)
{
  return ZeroBtMessage::create<BtChokeMessage>(data, dataLength);
}

void BtChokeMessage::doReceivedAction()
{
  if(isMetadataGetMode()) {
    return;
  }
  getPeer()->peerChoking(true);
  getBtMessageDispatcher()->doChokedAction();
  getBtRequestFactory()->doChokedAction();
}

bool BtChokeMessage::sendPredicate() const
{
  return !getPeer()->amChoking();
}

namespace {
struct ThisProgressUpdate : public ProgressUpdate {
  ThisProgressUpdate(std::shared_ptr<Peer>  peer,
                     BtMessageDispatcher* disp)
    : peer(std::move(peer)), disp(disp) {}
  virtual void update(size_t length, bool complete) CXX11_OVERRIDE
  {
    if(complete) {
      peer->amChoking(true);
      disp->doChokingAction();
    }
  }
  std::shared_ptr<Peer> peer;
  BtMessageDispatcher* disp;
};
} // namespace

std::unique_ptr<ProgressUpdate> BtChokeMessage::getProgressUpdate()
{
  return make_unique<ThisProgressUpdate>(getPeer(), getBtMessageDispatcher());
}

} // namespace aria2
